/*
|    file name -- dvrule.h
|===================================================================
|
|    Copyright (c) 1989 V.I. Corporation
|
|    dvrule.h - Declarations and defines for object rules.
|
*/

#ifndef DVRULE_H
#define DVRULE_H

typedef LONG RULE_ARG;

/* FOR INTERNAL USE ONLY */
#define V_NUM_ARGS 3    /* max of V_NUM_COND_ARGS and V_NUM_ACTION_ARGS */

#define V_NUM_COND_ARGS 3
typedef struct RULE_CONDITION
  {
  char type;
  RULE_ARG arg[V_NUM_COND_ARGS];
  } RULE_CONDITION;

#define V_NUM_ACTION_ARGS 2
typedef struct RULE_ACTION
  {
  char type;
  RULE_ARG  arg[V_NUM_ACTION_ARGS];
  struct RULE_ACTION *next;
  } RULE_ACTION;

/****************************** Rule Components ************************/
#define V_R_EVENT       1
#define V_R_CONDITION   2
#define V_R_ACTION      3

/****************************** Rule Events ************************/
#define V_RE_PICK		1
#define V_RE_DONE		2
#define V_RE_ACCEPT		3
#define V_RE_CANCEL		4
#define V_RE_DRAW		5	/* Drawings Only */
#define V_RE_UPDATE		6	/* Drawings Only */
#define V_RE_EVENT_USED		7
#define V_R_NUM_EVENTS		7

/************************* Rule Conditionals OPERANDS ***************/
#define V_RC_ALWAYS		1
#define V_RC_PICK_BUTTON	2	/* <> <> <button number> */
#define V_RC_PICK_ASCII		3	/* <> <> <key string> */
#define V_RC_DSV_VALUE		4	/* <dsv> <operator> <value> */
#define V_RC_DSV_DSV		5	/* <dsv> <operator> <dsv> */
#define V_RC_OBJ_VAR_VALUE	6	/* <> <operator> <value> */
#define V_R_NUM_CONDITIONS	6

/* Rule Conditionals OPERATORS ( =,!=,<,<=,>,>= ) */
#define V_RC_EQUAL		1
#define V_RC_NOT_EQUAL		2
#define V_RC_LESS_THAN		3
#define V_RC_LESS_EQUAL_THAN	4
#define V_RC_GREATER_THAN	5
#define V_RC_GREATER_EQUAL_THAN	6
#define V_RC_NUM_OPERATORS	6

/***************************** Rule Actions *************************/
#define V_RA_NEXT		1	/* <view name> */
#define V_RA_PREVIOUS		2

/* ADD/DEL_OVERLAY */
#define V_RA_OVERLAY_VIEW	3  	/* <view name> */
#define V_RA_DEL_OVERLAY_VIEW   4   	/* <view name> */
#define V_RA_OVERLAY_OBJ	5 	/* <obj name> <from view name > */

#define V_RA_DEL_OBJECT    	6  	/* <obj name> <from view name> */

/* TRUE POPUPS */
#define V_RA_POPUP_AT		7       /* <obj name> <from view name> */
#define V_RA_ERASE_POPUP_AT	8       /* obsolete, same as V_RA_DEL_OBJ */ 
#define V_RA_ERASE_ALL_POPUP_AT	9       

/* MISC ACTIONS */
#define V_RA_REDRAW		10
#define V_RA_QUIT	 	11
#define V_RA_NOTHING		12

#define V_RA_SYSTEM_CALL	13 	/* <call string> */

#define V_RA_ERASE_ALL_OVERLAYS	14 	

#define V_RA_START_DYNAMICS	15
#define V_RA_STOP_DYNAMICS	16
#define V_RA_INC_UPDATE_RATE	17
#define V_RA_DEC_UPDATE_RATE	18

#define V_RA_SET_DSV		19	/* <dsv> <value> */
#define V_RA_INC_DSV            20      /* <dsv> <amount> */
#define V_RA_DEC_DSV            21      /* <dsv> <amount> */

#define V_R_NUM_ACTIONS 	21

#endif /* DVRULE_H */

